@@ -42,7 +42,7 @@ class ModelEntry(ScheduleEntry):
         self.model = model
 
         if not model.last_run_at:
-            model.last_run_at = datetime.now()
+            model.last_run_at = self._default_now()
         self.last_run_at = model.last_run_at
 
     def is_due(self):
@@ -50,6 +50,9 @@ class ModelEntry(ScheduleEntry):
             return False, 5.0   # 5 second delay for re-enable.
         return self.schedule.is_due(self.last_run_at)
 
+    def _default_now(self):
+        return datetime.now()
+
     def next(self):
         self.model.last_run_at = datetime.now()
         self.model.total_run_count += 1
@@ -158,21 +161,19 @@ class DatabaseScheduler(Scheduler):
     @transaction.commit_manually
     def flush(self):
         self.logger.debug("Writing dirty entries...")
-        if not self._dirty:
-            return
         try:
             while self._dirty:
                 try:
                     name = self._dirty.pop()
                     self.schedule[name].save()
+                    self._last_flush = time()
                 except (KeyError, ObjectDoesNotExist):
-                    continue
+                    pass
         except:
             transaction.rollback()
             raise
         else:
             transaction.commit()
-            self._last_flush = time()
 
     def update_from_dict(self, dict_):
         s = {}
