@@ -19,7 +19,7 @@ ADMINS = (
 
 TEST_RUNNER = "django_nose.run_tests"
 here = os.path.abspath(os.path.dirname(__file__))
-COVERAGE_EXCLUDE_MODULES = ("djcelery.__init__",
+COVERAGE_EXCLUDE_MODULES = ("djcelery",
                             "djcelery.tests.*",
                             "djcelery.management.*",
                             "djcelery.contrib.*",
@@ -49,11 +49,16 @@ CELERY_QUEUES = {"testcelery": {"binding_key": "testcelery"}}
 MANAGERS = ADMINS
 
 DATABASE_ENGINE = 'sqlite3'
+DATABASE_HOST = 'djcelery-test-db'
 DATABASE_USER = ''
 DATABASE_PASSWORD = ''
-DATABASE_HOST = ''
 DATABASE_PORT = ''
 
+DATABASES = {
+    "default": {
+        "ENGINE": "django.db.backends.sqlite3",
+        "NAME": "djcelery-test-db",
+
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
